@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 ##########################################################################
@@ -39,11 +38,12 @@ from RecordTimer import parseEvent, RecordTimerEntry
 from timer import TimerEntry
 from Screens.InfoBar import InfoBar
 from Tools.Directories import fileExists
-from enigma import eEPGCache, eDVBVolumecontrol, eServiceCenter, eServiceReference
+from enigma import eDVBVolumecontrol, eServiceCenter, eServiceReference
 
 from Plugins.Extensions.OpenWebif.controllers.i18n import _
-from Plugins.Extensions.OpenWebif.controllers.defaults import OPENWEBIFVER, TRANSCODING
+from Plugins.Extensions.OpenWebif.controllers.defaults import OPENWEBIFVER, TRANSCODING, TEXTINPUTSUPPORT
 from Plugins.Extensions.OpenWebif.controllers.utilities import removeBad, removeBad2
+from Plugins.Extensions.OpenWebif.controllers.epg import EPG
 
 try:
 	from boxbranding import getBoxType, getMachineBuild, getMachineBrand, getMachineName, getImageDistro, getImageVersion, getImageBuild, getOEVersion, getDriverDate
@@ -106,7 +106,7 @@ def getLinkSpeed(iface):
 	except:  # nosec # noqa: E722
 		if os.path.isdir('/sys/class/net/' + iface + '/wireless'):
 			try:
-				speed = os.popen('iwconfig ' + iface + ' | grep "Bit Rate"').read().split(':')[1].split(' ')[0]
+				speed = os.popen('iwlist ' + iface + ' bitrate | grep "Bit Rate"').read().split(':')[1].split(' ')[0]
 			except:  # nosec # noqa: E722
 				pass
 	speed = str(speed) + " MBit/s"
@@ -513,7 +513,6 @@ def getInfo(session=None, need_fullinfo=False):
 		try:
 			#  gets all current stream clients for images using eStreamServer
 			#  TODO: get tuner info for streams
-			#  TODO: get recoding/timer info if more than one
 			info['streams'] = GetStreamInfo()
 
 			recs = NavigationInstance.instance.getRecordings()
@@ -525,18 +524,19 @@ def getInfo(session=None, need_fullinfo=False):
 					s_name = sinfo["name"] + ' (' + sinfo["ip"] + ')'
 					print("[OpenWebif] -D- s_name '%s'" % s_name)
 
-				sname = ''
-				timers = []
+				serviceNames = {}
 				for timer in NavigationInstance.instance.RecordTimer.timer_list:
 					if timer.isRunning() and not timer.justplay:
-						timers.append(removeBad(timer.service_ref.getServiceName()))
+						timer_rs = timer.record_service
+						feinfo = timer_rs and hasattr(timer_rs, "frontendInfo") and timer_rs.frontendInfo()
+						fedata = feinfo and hasattr(feinfo, "getFrontendData") and feinfo.getFrontendData()
+						tuner_num = fedata and "tuner_number" in fedata and fedata.get("tuner_number")
+						if tuner_num is not None:
+							if tuner_num in serviceNames:  # this tuner is recording more than one timer
+								serviceNames[tuner_num] += ", " + removeBad(timer.service_ref.getServiceName())
+							else:
+								serviceNames[tuner_num] = removeBad(timer.service_ref.getServiceName())
 						print("[OpenWebif] -D- timer '%s'" % timer.service_ref.getServiceName())
-# TODO: more than one recording
-				if len(timers) == 1:
-					sname = timers[0]
-
-				if sname == '' and s_name != '':
-					sname = s_name
 
 				print("[OpenWebif] -D- recs count '%d'" % len(recs))
 
@@ -547,7 +547,10 @@ def getInfo(session=None, need_fullinfo=False):
 						cur_info = feinfo.getTransponderData(True)
 						if cur_info:
 							nr = frontendData['tuner_number']
-							info['tuners'][nr]['rec'] = getOrbitalText(cur_info) + ' / ' + sname
+							if nr in serviceNames:
+								info['tuners'][nr]['rec'] = getOrbitalText(cur_info) + ' / ' + serviceNames[nr]
+							else:
+								info['tuners'][nr]['rec'] = getOrbitalText(cur_info) + ' / ' + s_name
 
 			service = session.nav.getCurrentService()
 			if service is not None:
@@ -574,6 +577,7 @@ def getInfo(session=None, need_fullinfo=False):
 	except Exception as error:
 		print("[OpenWebif] -D- RecordTimerEntry check %s" % error)
 
+	info['textinputsupport'] = TEXTINPUTSUPPORT
 	STATICBOXINFO = info
 	return info
 
@@ -586,8 +590,8 @@ def getStreamServiceAndEvent(ref):
 	servicereference = ServiceReference(ref)
 	if servicereference:
 		sname = removeBad(servicereference.getServiceName())
-	epg = eEPGCache.getInstance()
-	event = epg and epg.lookupEventTime(ref, -1, 0)
+	epg = EPG()
+	event = epg.getCurrentEvent(ref)
 	if event:
 		eventname = event.getEventName()
 	return sname, eventname
@@ -628,7 +632,7 @@ def GetStreamInfo():
 					"name": servicename,
 					"eventname": eventname,
 					"ip": stream.clientIP,
-					"type": "S" # TODO : Transcoding
+					"type": "S"  # TODO : Transcoding
 				})
 
 	return streams
