@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 from time import localtime, strftime
 from six.moves.urllib.parse import quote
@@ -14,7 +13,7 @@ class renderEvtBlock:
             <div style="width:144px; float:left">
                 <div class="title">%s</div>%s
             </div>
-            <div style="clear:left"></div>
+            <div style="clear:left;height:2px;%s"></div>
         </div>
         """
 
@@ -24,8 +23,12 @@ class renderEvtBlock:
         else:
             shortdesc = ''
 
+        timerbar = ""
+
         if event['timerStatus'] != '':
-            timerEventSymbol = '<div class="%s">%s</div>' % (event['timerStatus'], tstrings['timer'])
+            text = event['timer']['text']
+            timerEventSymbol = '<div class="%s">%s</div>' % (event['timerStatus'], text)
+            timerbar = "background-color:red;"
         else:
             timerEventSymbol = ''
 
@@ -35,4 +38,4 @@ class renderEvtBlock:
             strftime("%H:%M", localtime(event['begin_timestamp'])),
             timerEventSymbol,
             event['title'],
-            shortdesc)
+            shortdesc, timerbar)
