@@ -520,7 +520,7 @@ class GetipklistLs(Screen):
         # self.onShown.append(self.get_list)
 
     def downloadxmlpage(self):
-        url = 'http://sat-lodge.it/xml/PluginEmulators.xml'    
+        url = 'https://webplusfeeds.sat-lodge.it/xml/PluginEmulators.xml'    
 
         getPage(url).addCallback(self._gotPageLoad).addErrback(self.errorLoad)
 
@@ -641,13 +641,13 @@ class GetipkLs(Screen):
         if self.selection == '':
             self.session.openWithCallback(self.callMyMsg, MessageBox, _('Installare...'), MessageBox.TYPE_YESNO)
         else:
-            self.session.open(Console, _('Installing: %s') % dom, ['opkg install -force-overwrite %s' % com])
+            self.session.open(Console, _('Installing: %s') % dom, ['opkg install --force-overwrite --force-depends %s' % com])
 
     def callMyMsg(self, result):
         if result:
             dom = self.dom
             com = self.com
-            self.session.open(Console, _('Installing: %s') % dom, ['ipkg install -force-overwrite %s' % com])
+            self.session.open(Console, _('Installing: %s') % dom, ['opkg install --force-overwrite --force-depends %s' % com])
 
 def startConfig(session, **kwargs):
         session.open(slManager)
